<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <location filename="../../UnitTest.ui" line="16"/>
      <source>FreeCAD UnitTest</source>
      <translation>Środowisko pracy FreeCAD UnitTest</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="31"/>
      <source>Failures and errors</source>
      <translation>Awarie i błędy</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="47"/>
      <source>Description</source>
      <translation>Opis</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="82"/>
      <source>&amp;Start</source>
      <translation>&amp;Uruchom</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="85"/>
      <source>Alt+S</source>
      <translation>Alt + S</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="114"/>
      <source>&amp;Help</source>
      <translation>&amp;Pomoc</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="117"/>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="127"/>
      <source>&amp;About</source>
      <translation>&amp;O programie</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="130"/>
      <source>Alt+A</source>
      <translation>ALT + A</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="140"/>
      <source>&amp;Close</source>
      <translation>&amp;Zamknij</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="143"/>
      <source>Alt+C</source>
      <translation>Alt + C</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="161"/>
      <source>Idle</source>
      <translation>Bezczynny</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="168"/>
      <source>Progress</source>
      <translation>Postęp</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="197"/>
      <source>Remaining:</source>
      <translation>Pozostało:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="214"/>
      <source>Errors:</source>
      <translation>Błędy:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="231"/>
      <source>Failures:</source>
      <translation>Awarie:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="248"/>
      <source>Run:</source>
      <translation>Wykonaj:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="258"/>
      <source>Test</source>
      <translation>Test</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="270"/>
      <source>Select test name:</source>
      <translation>Wybierz nazwę testu:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <location filename="../../UnitTestImp.cpp" line="164"/>
      <source>Help</source>
      <translation>Pomoc</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="164"/>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>Wprowadź nazwę obiektu typu callable, który po wywołaniu zwróci TestCase.
Kliknij 'start', a utworzony w ten sposób test zostanie uruchomiony.

Kliknij dwukrotnie na pozycję z błędem w widoku drzewa, aby zobaczyć więcej informacji na jego temat, w tym śledzenie stosu.</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="176"/>
      <source>About FreeCAD UnitTest</source>
      <translation>O środowisku pracy FreeCAD UnitTest</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="176"/>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>Copyright (c) Werner Mayer

Środowisko pracy FreeCAD UnitTest jest częścią FreeCAD i wspiera pisanie własnych testów dla własnych modułów.</translation>
    </message>
  </context>
</TS>
